/* $Id: cpl_dfs.h,v 1.10 2008/05/27 09:37:52 llundin Exp $
 *
 * This file is part of the IIINSTRUMENT Pipeline
 * Copyright (C) 2002,2003 European Southern Observatory
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/*
 * $Author: llundin $
 * $Date: 2008/05/27 09:37:52 $
 * $Revision: 1.10 $
 * $Name: cpl-4_2_0b3 $
 */

#ifndef CPL_DFS_H
#define CPL_DFS_H

#include <cpl_imagelist.h>
#include <cpl_table.h>
#include <cpl_frameset.h>
#include <cpl_propertylist.h>
#include <cpl_parameterlist.h>
#include <cpl_error.h>

CPL_BEGIN_DECLS

/*-----------------------------------------------------------------------------
                                 Defines
 -----------------------------------------------------------------------------*/

#define CPL_DFS_FITS ".fits"
#define CPL_DFS_PAF ".paf"


/*----------------------------------------------------------------------------*/
/**
   @ingroup cpl_dfs
   @brief  The name of the Product Category key
   @see cpl_dfs_save_image()
   @note A pipeline product must contain a string property with this name
 */
/*----------------------------------------------------------------------------*/
#define CPL_DFS_PRO_CATG "ESO PRO CATG"

/*----------------------------------------------------------------------------*/
/**
   @ingroup cpl_dfs
   @brief  The name of the Product Type key
   @see cpl_dfs_save_image()
   @note A pipeline product should contain a string property with this name

 */
/*----------------------------------------------------------------------------*/
#define CPL_DFS_PRO_TYPE "ESO PRO TYPE"

/*----------------------------------------------------------------------------*/
/**
   @ingroup cpl_dfs
   @brief  The name of the Product Tech key
   @see cpl_dfs_save_image()
   @note A pipeline product should contain a string property with this name

 */
/*----------------------------------------------------------------------------*/
#define CPL_DFS_PRO_TECH "ESO PRO TECH"

/*----------------------------------------------------------------------------*/
/**
   @ingroup cpl_dfs
   @brief  The name of the Product Science key
   @see cpl_dfs_save_image()
   @note A pipeline product should contain a boolean property with this name
 */
/*----------------------------------------------------------------------------*/
#define CPL_DFS_PRO_SCIENCE "ESO PRO SCIENCE"


/*-----------------------------------------------------------------------------
                              Function prototypes
 -----------------------------------------------------------------------------*/

cpl_error_code cpl_dfs_save_image(cpl_frameset *,
                                  const cpl_parameterlist *,
                                  const cpl_frameset *,
                                  const cpl_image *,
                                  cpl_type_bpp,
                                  const char *,
                                  const char *,
                                  const cpl_propertylist *,
                                  const char *,
                                  const char *,
                                  const char *);

cpl_error_code cpl_dfs_save_propertylist(cpl_frameset *,
                                         const cpl_parameterlist *,
                                         const cpl_frameset *,
                                         const char *,
                                         const char *,
                                         const cpl_propertylist *,
                                         const char *,
                                         const char *,
                                         const char *);

cpl_error_code cpl_dfs_save_imagelist(cpl_frameset *,
                                      const cpl_parameterlist *,
                                      const cpl_frameset *,
                                      const cpl_imagelist *,
                                      cpl_type_bpp,
                                      const char *,
                                      const char *,
                                      const cpl_propertylist *,
                                      const char *,
                                      const char *,
                                      const char *);

cpl_error_code cpl_dfs_save_table(cpl_frameset *,
                                  const cpl_parameterlist *,
                                  const cpl_frameset *,
                                  const cpl_table *,
                                  const cpl_propertylist *,
                                  const char *,
                                  const char *,
                                  const cpl_propertylist *,
                                  const char *,
                                  const char *,
                                  const char *);

cpl_error_code cpl_dfs_save_paf(const char *, const char *,
                                const cpl_propertylist *, const char *);

cpl_error_code cpl_dfs_setup_product_header(cpl_propertylist *, 
                                            const cpl_frame *, 
                                            const cpl_frameset *, 
                                            const cpl_parameterlist *, 
                                            const char *,
                                            const char *,
                                            const char *);

cpl_error_code cpl_dfs_update_product_header(cpl_frameset *);

CPL_END_DECLS

#endif
